﻿using Hotline.File;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Snapshot;
using Hotline.Share.Tools;
using Hotline.Snapshot;
using Hotline.Snapshot.Interfaces;
using Mapster;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;

namespace Hotline.Application.Snapshot;
public class IndustryApplication : IIndustryApplication, IScopeDependency
{
    private readonly IIndustryRepository _industryRepository;
    private readonly IFileRepository _fileRepository;

    public IndustryApplication(IIndustryRepository industryRepository, IFileRepository fileRepository)
    {
        _industryRepository = industryRepository;
        _fileRepository = fileRepository;
    }

    /// <summary>
    /// 新增行业
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    /// <exception cref="NotImplementedException"></exception>
    public async Task<string> AddIndustryAsync(AddIndustryDto dto, CancellationToken cancellationToken)
    {
        var entity = dto.Adapt<Industry>();
        var id = await _industryRepository.AddAsync(entity, cancellationToken);
        if (dto.Files.NotNullOrEmpty())
        {
            var fileEntities = dto.Files.Adapt<List<Hotline.File.File>>();
            fileEntities.ForEach(m => m.Key = id);
            await _fileRepository.AddRangeAsync(fileEntities, cancellationToken);
        }
        return id;
    }

    public ISugarQueryable<IndustryItemsOutDto> GetIndustres(IndustryListInDto dto)
    {
        var query = _industryRepository.Queryable()
            .WhereIF(dto.Name.NotNullOrEmpty(), m => m.Name.Contains(dto.Name))
            .WhereIF(dto.ApproveOrgName.NotNullOrEmpty(), m => m.ApproveOrgName.Contains(dto.ApproveOrgName))
            .Select<IndustryItemsOutDto>();
        

        return query;
    }
}
